package gs.smolban.model

/** Enumeration that describes the status of a [[Ticket]] in Smolban. Smolban
  * does not yet support custom status/workflow.
  *
  * @param value
  *   The string value of the status.
  */
sealed abstract class Status(val value: String)

object Status:

  /** This ticket is new, and ready to be started. New tickets may be put into
    * progress or canceled.
    */
  case object Ready extends Status("ready")

  /** This ticket is being worked on actively. In progress tickets can be
    * paused, completed, or canceled.
    */
  case object InProgress extends Status("in_progress")

  /** This ticket was being worked on, but was temporarily stopped. Paused
    * tickets may be put into progress or canceled.
    */
  case object Paused extends Status("paused")

  /** This ticket was driven to completion. The work is done. Once in this
    * state, the status may no longer change.
    */
  case object Complete extends Status("complete")

  /** This ticket was canceled for some reason. Once in this state, the status
    * may no longer change.
    */
  case object Canceled extends Status("canceled")

end Status
