package gs.smolban.model.users

import cats.Show
import gs.smolban.model.CreatedAt
import gs.uuid.v0.UUID

case class User(
  id: User.Id,
  createdAt: CreatedAt,
  username: Username
)

object User:

  given CanEqual[User, User] = CanEqual.derived

  /** Unique identifier for a [[User]]. This is an opaque type for a UUID.
    */
  opaque type Id = UUID

  object Id:

    /** Instantiate a new [[User.Id]].
      *
      * @param id
      *   The underlying UUID.
      * @return
      *   The new [[User.Id]] instance.
      */
    def apply(id: UUID): Id = id

    given CanEqual[Id, Id] = CanEqual.derived

    given Show[Id] = _.toUUID().withoutDashes()

    extension (id: Id)
      /** Unwrap this User ID.
        *
        * @return
        *   The underlying UUID value.
        */
      def toUUID(): UUID = id

  end Id

end User
